c
      subroutine fault(kx,ky,d1,d2,z,cux,cuy,cuz,
     +                               cvx,cvy,cvz,
     +                               cwx,cwy,cwz,
     +                               c3x,c3y,c3z)
c
c  input
c    kx  - x wavenumber        (1/km)
c    ky  - y wavenumber        (1/km)
c    d1  - bottom of fault d1 < d2 < 0. (km)
c    d2  - top of fault        (km)
c    z   - observation plane   (km)
c
c  output
c    cux,cuy,cuz  - elements of force/displacement matrix
c    cvx,cvy,cvz               (km**2/Pa)
c    cwx,cwy,cwz
c    c3x,c3y,c3z  - non-zero vertical stress at surface z=0
c                              (km)
c
      implicit complex (c)
      implicit real*4 (k)
c
c  routine to compute the greens function for a fault element
c
      common/elastic/rlam,rmu,rc,rd,alph,pi
c
      if (kx.eq.0.and.ky.eq.0.) then
        cux=cmplx(0.,0.)
        cuy=cmplx(0.,0.)
        cuz=cmplx(0.,0.)
        cvx=cmplx(0.,0.)
        cvy=cmplx(0.,0.)
        cvz=cmplx(0.,0.)
        cwx=cmplx(0.,0.)
        cwy=cmplx(0.,0.)
        cwz=cmplx(0.,0.)
        cwz=cmplx(0.,0.)
        c3y=cmplx(0.,0.)
        c3z=cmplx(0.,0.)
        c3z=cmplx(0.,0.)
      else
        kh2=kx*kx+ky*ky
        kh=sqrt(kh2)
        B=2*pi*kh
        B2=B*B
c
        Bs1=B*(z-d1)
        Bs2=B*(z-d2)
        Bi1=B*(z+d1)
        Bi2=B*(z+d2)
        if(Bs1.gt.50.) then 
          es1=0.
        else
          es1=exp(-Bs1)
        endif
        if(Bs2.gt.50.) then 
          es2=0.
        else
          es2=exp(-Bs2)
        endif
        if(Bi1.lt.-50.) then
          ei1=0.
        else
          ei1=exp(+Bi1)
        endif
        if(Bi2.lt.-50.) then
          ei2=0.
        else
          ei2=exp(+Bi2)
        endif
c
        kxx=(kx*kx)/kh2
        kyy=(ky*ky)/kh2
        kxy=(kx*ky)/kh2
c
        uxs=(rc/B2)*(es2*(rd+kyy-kxx*(1+Bs2))-es1*(rd+kyy-kxx*(1+Bs1)))
        uxi=(rc/B2)*(ei2*(rd+kyy-kxx*(1-Bi2))-ei1*(rd+kyy-kxx*(1-Bi1)))
        cux=cmplx(uxs+uxi,0)
c
        uys=-(rc/B2)*kxy*(es2*(2.+Bs2)-es1*(2.+Bs1))
        uyi=-(rc/B2)*kxy*(ei2*(2.-Bi2)-ei1*(2.-Bi1))
        cuy=cmplx(uys+uyi,0)
c
        uzs=-(rc/B2)*(kx/kh)*(es2*(1.+Bs2)-es1*(1.+Bs1))
        uzi= (rc/B2)*(kx/kh)*(ei2*(1.-Bi2)-ei1*(1.-Bi1))
        cuz=cmplx(0,uzs-uzi)
c
        cvx=cmplx(uys+uyi,0.)
c
        vys= (rc/B2)*(es2*(rd+kxx-kyy*(1+Bs2))-es1*(rd+kxx-kyy*(1+Bs1)))
        vyi= (rc/B2)*(ei2*(rd+kxx-kyy*(1-Bi2))-ei1*(rd+kxx-kyy*(1-Bi1)))
        cvy=cmplx(vys+vyi,0.)
c
        vzs=-(rc/B2)*(ky/kh)*(es2*(1.+Bs2)-es1*(1.+Bs1))
        vzi= (rc/B2)*(ky/kh)*(ei2*(1.-Bi2)-ei1*(1.-Bi1))
        cvz=cmplx(0.,vzs-vzi)
c
        cwx=cmplx(0.,uzs+uzi)
c
        cwy=cmplx(0.,vzs+vzi)
c
        wzs= (rc/B2)*(es2*(rd+1.+Bs2)-es1*(rd+1.+Bs1))
        wzi= (rc/B2)*(ei2*(rd+1.-Bi2)-ei1*(rd+1.-Bi1))
        cwz=cmplx(wzs-wzi,0.)
c
c   compute the surface traction components
c
        rl2m=rlam+2.*rmu
        Bd1=B*d1
        Bd2=B*d2
        if(Bd1.lt.-50) then
          e1=0.
        else
          e1=exp(Bd1)
        endif
        if(Bd2.lt.-50) then
          e2=0.
        else
          e2=exp(Bd2)
        endif
        arg1=e1*(alph*Bd1-rlam/rl2m)
        arg2=e2*(alph*Bd2-rlam/rl2m)
        arg3=e1*(alph*Bd1-rmu/rl2m-2*alph)
        arg4=e2*(alph*Bd2-rmu/rl2m-2*alph)
        c3x=cmplx(0.,-(arg2-arg1)*kx/(B*kh))
        c3y=cmplx(0.,-(arg2-arg1)*ky/(B*kh))
        c3z=cmplx((arg4-arg3)/B,0.)
      endif
      return
      end
c
